PAWpySeed: Class Members - Variables

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

- All
- Functions
- Variables

- a
- b
- c
- d
- e
- f
- g
- i
- k
- l
- m
- n
- o
- p
- r
- s
- t
- u
- v
- w

### - a -

- aecorecharge : pawpyseed.core.wavefunction.Pseudopotential
- aepotential : pawpyseed.core.wavefunction.Pseudopotential
- aepw_overlap_matrix : ppot
- aewave : funcset
- aewave_spline : funcset
- aewaves : pawpyseed.core.wavefunction.Pseudopotential
- atomicdensity : pawpyseed.core.wavefunction.Pseudopotential
- augs : pawpyseed.core.wavefunction.Pseudopotential

### - b -

- band_props : pawpyseed.core.noncollinear.NCLWavefunction , pawpyseed.core.wavefunction.Wavefunction
- bandgap : pawpyseed.analysis.defect_composition.PawpyData
- bands : kpoint
- bulk_fw_sets : pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle

### - c -

- CAs : band
- cbm : pawpyseed.analysis.defect_composition.PawpyData
- coord : real_proj_site
- coredensity : pawpyseed.core.wavefunction.Pseudopotential
- cr : pawpyseed.core.noncollinear.NCLWavefunction , pawpyseed.core.wavefunction.Wavefunction
- CRs : band
- Cs : band
- curr : WAVECAR_FILE

### - d -

- data : pawpyseed.analysis.defect_composition.PawpyData
- dcoords : pswf
- dense_kgrid : ppot
- dense_kwave : funcset
- dense_kwave_spline : funcset
- densities : pawpyseed.analysis.defect_composition.PawpyData
- diff_overlap_matrix : ppot
- diffwave : funcset
- diffwave_spline : funcset
- dim : pawpyseed.core.noncollinear.NCLWavefunction , pawpyseed.core.wavefunction.Wavefunction
- down_projections : band
- drho : sbt_descriptor
- dt : sbt_descriptor
- dwo : pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle

### - e -

- efermi : pawpyseed.analysis.defect_composition.PawpyData
- elem : real_proj_site
- encut : pswf
- energies : pawpyseed.analysis.defect_composition.PawpyData
- energy : band
- energy_levels : pawpyseed.analysis.defect_composition.BulkCharacter
- expansion : kpoint

### - f -

- fftg : pswf
- fp : WAVECAR_FILE
- func_num : real_proj
- funcs : ppot
- fw_id : pawpyseed.analysis.run_pawpy.DummyFirework

### - g -

- G_bounds : pswf
- gradxc : pawpyseed.core.wavefunction.Pseudopotential
- grid : pawpyseed.core.wavefunction.Pseudopotential
- gridsize : real_proj_site
- Gs : kpoint

### - i -

- index : real_proj_site
- indices : real_proj_site
- is_ncl : pswf

### - k -

- k : kpoint
- kappamin : sbt_descriptor
- kinetic : pawpyseed.core.wavefunction.Pseudopotential
- kmin : sbt_descriptor
- kpts : pswf
- ks : sbt_descriptor
- kwave : funcset
- kwave_grid : ppot
- kwave_spline : funcset

### - l -

- l : funcset , rayleigh_set , real_proj
- lattice : pswf
- launch_dir : pawpyseed.analysis.run_pawpy.PathHolder
- launches : pawpyseed.analysis.run_pawpy.DummyFirework
- lmax : ppot , sbt_descriptor
- localnum : pawpyseed.core.wavefunction.Pseudopotential
- localpart : pawpyseed.core.wavefunction.Pseudopotential
- ls : pawpyseed.core.wavefunction.Pseudopotential , projection

### - m -

- m : real_proj
- metadata : pawpyseed.analysis.corrections.DelocalizedStatePerturbationCorrection , pawpyseed.analysis.corrections.PerturbationCorrection
- method : pawpyseed.core.projector.Projector
- METHODS : pawpyseed.core.projector.Projector
- ms : projection
- msg : pawpyseed.core.utils.PAWpyError , pawpyseed.core.utils.PAWpyWarning
- mult_table : sbt_descriptor

### - n -

- N : band
- n : band
- N : sbt_descriptor
- name : pawpyseed.analysis.run_pawpy.DummyFirework
- nband : pswf
- ndata : pawpyseed.core.wavefunction.Pseudopotential
- nonlocalprojs : pawpyseed.core.wavefunction.Pseudopotential
- ns : projection
- nspin : pswf
- num_aug_overlap_sites : pswf
- num_bands : kpoint
- num_cart_gridpts : ppot
- num_elems : pawpyseed.core.wavefunction.Wavefunction , pswf
- num_indices : real_proj_site
- num_projs : ppot , projection , pswf , real_proj_site
- num_sites : pawpyseed.core.wavefunction.Wavefunction , pswf
- num_waves : band , kpoint
- nwk : pswf

### - o -

- occ : band
- overlaps : projection , pswf

### - p -

- paths : real_proj_site
- pps : pawpyseed.core.wavefunction.CoreRegion , pswf
- proj : funcset
- proj_grid : ppot
- proj_gridsize : ppot
- proj_spline : funcset
- projections : band
- projgrid : pawpyseed.core.wavefunction.Pseudopotential
- projs : real_proj_site
- pscorecharge : pawpyseed.core.wavefunction.Pseudopotential
- pspotential : pawpyseed.core.wavefunction.Pseudopotential
- pspw_overlap_matrix : ppot
- pswave : funcset
- pswave_spline : funcset
- pswaves : pawpyseed.core.wavefunction.Pseudopotential

### - r -

- realprojs : pawpyseed.core.wavefunction.Pseudopotential
- recipprojs : pawpyseed.core.wavefunction.Pseudopotential
- reclattice : pswf
- rhomin : sbt_descriptor
- rmax : pawpyseed.core.wavefunction.Pseudopotential , ppot , real_proj_site
- rmin : sbt_descriptor
- rs : sbt_descriptor

### - s -

- site_cat : pawpyseed.core.projector.Projector
- smooth_diffwave : funcset
- smooth_diffwave_spline : funcset
- smooth_grid : ppot
- start : WAVECAR_FILE
- step : pawpyseed.core.wavefunction.Pseudopotential
- structure : pawpyseed.analysis.defect_composition.PawpyData , pawpyseed.core.noncollinear.NCLWavefunction , pawpyseed.core.wavefunction.Wavefunction
- symprec : pawpyseed.core.wavefunction.Wavefunction

### - t -

- T : pawpyseed.core.wavefunction.Pseudopotential
- terms : rayleigh_set
- total_projs : ppot , projection , real_proj_site
- type : WAVECAR_FILE

### - u -

- up : kpoint
- up_projections : band

### - v -

- values : projgrid , real_proj
- vbm : pawpyseed.analysis.defect_composition.PawpyData

### - w -

- wave_grid : ppot
- wave_gridsize : ppot
- wave_projections : band
- wave_rmax : ppot
- weight : kpoint
- wp_num : pswf